@@ -77,7 +77,7 @@ class MachineSet(NamespacedResource):
         self.machine_type = machine_type
         self.provider_spec = provider_spec or {}
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             _spec, _metadata, _labels = ("spec", "metadata", "labels")
@@ -178,7 +178,7 @@ class MachineSet(NamespacedResource):
         super().to_dict()
         self.res.update({"spec": {"replicas": replicas}})
 
-        self.logger.info(f"Scale machine-set from {self.desired_replicas} replicas to {replicas} replicas")
+        self.logger.info(f"Scale machine-set from {self.desired_replicas} replicas to" f" {replicas} replicas")
         self.update(resource_dict=self.res)
         if wait:
             return self.wait_for_replicas(timeout=wait_timeout, sleep=sleep)
